==> netdata-1.47.4.tar.gz: netdata-v1.47.4/src/health/guides/httpcheck/httpcheck_web_service_up.md <==
### Understand the alert

The `httpcheck_web_service_up` alert monitors the liveness status of an HTTP endpoint by checking its response over the past minute. If the success percentage is below 75%, this alert will trigger, indicating that the web service may be experiencing issues.

### What does an HTTP endpoint liveness status mean?

An HTTP endpoint is like a door where clients make requests to access web services or APIs. The liveness status reveals whether the service is available and responding to client requests. Ideally, this success percentage should be near 100%, indicating that the endpoint is consistently accessible.

### Troubleshoot the alert

1. Check logs for any errors or warnings related to the web server or application.

   Depending on your web server or application, look for log files that may provide insights into the causes of the issues. Some common log locations are:

   - Apache: `/var/log/apache2/`
   - Nginx: `/var/log/nginx/`
   - Node.js: Check your application-specific log location.

2. Examine server resources such as CPU, memory, and disk usage.

   High resource usage can cause web services to become slow or unresponsive. Use system monitoring tools like `top`, `htop`, or `free` to check the resource usage.

3. Test the HTTP endpoint manually.

   You can use tools like `curl`, `wget`, or `httpie` to send requests to the HTTP endpoint and inspect the responses. Examine the response codes, headers, and contents to spot any problems.

   Example using `curl`:

   ```
   curl -I http://example.com/some/endpoint
   ```

4. Check for network issues between the monitoring agent and the HTTP endpoint.

   Use tools like `ping`, `traceroute`, or `mtr` to check for network latency or packet loss between the monitoring agent and the HTTP endpoint.

5. Review the web server or application configuration.

   Ensure the web server and application configurations are correct and not causing issues. Look for misconfigurations, incorrect settings, or other issues that may affect the liveness of the HTTP endpoint.

### Useful resources

1. [Monitoring Linux Performance with vmstat and iostat](https://www.tecmint.com/linux-performance-monitoring-with-vmstat-and-iostat-commands/)
2. [16 Useful Bandwidth Monitoring Tools to Analyze Network Usage in Linux](https://www.tecmint.com/linux-network-bandwidth-monitoring-tools/)

==> netdata-v2.6.2.tar.gz: netdata-v2.6.2/src/health/guides/httpcheck/httpcheck_web_service_up.md <==
### Understand the alert

The `httpcheck_web_service_up` alert monitors the liveness status of an HTTP endpoint by checking its response over the past minute. If the success percentage is below 75%, this alert will trigger, indicating that the web service may be experiencing issues.

### What does an HTTP endpoint liveness status mean?

An HTTP endpoint is like a door where clients make requests to access web services or APIs. The liveness status reveals whether the service is available and responding to client requests. Ideally, this success percentage should be near 100%, indicating that the endpoint is consistently accessible.

### Troubleshoot the alert

1. Check logs for any errors or warnings related to the web server or application.

   Depending on your web server or application, look for log files that may provide insights into the causes of the issues. Some common log locations are:

   - Apache: `/var/log/apache2/`
   - Nginx: `/var/log/nginx/`
   - Node.js: Check your application-specific log location.

2. Examine server resources such as CPU, memory, and disk usage.

   High resource usage can cause web services to become slow or unresponsive. Use system monitoring tools like `top`, `htop`, or `free` to check the resource usage.

3. Test the HTTP endpoint manually.

   You can use tools like `curl`, `wget`, or `httpie` to send requests to the HTTP endpoint and inspect the responses. Examine the response codes, headers, and contents to spot any problems.

   Example using `curl`:

   ```
   curl -I http://example.com/some/endpoint
   ```

4. Check for network issues between the monitoring Agent and the HTTP endpoint.

   Use tools like `ping`, `traceroute`, or `mtr` to check for network latency or packet loss between the monitoring Agent and the HTTP endpoint.

5. Review the web server or application configuration.

   Ensure the web server and application configurations are correct and not causing issues. Look for misconfigurations, incorrect settings, or other issues that may affect the liveness of the HTTP endpoint.

### Useful resources

1. [Monitoring Linux Performance with vmstat and iostat](https://www.tecmint.com/linux-performance-monitoring-with-vmstat-and-iostat-commands/)
2. [16 Useful Bandwidth Monitoring Tools to Analyze Network Usage in Linux](https://www.tecmint.com/linux-network-bandwidth-monitoring-tools/)
